==> flame_forge2d-0.12.2.tar.gz: README.md <==
<p align="center">
  <a href="https://flame-engine.org">
    <img alt="flame" width="300px" src="https://raw.githubusercontent.com/flame-engine/forge2d/main/design/with-text.png">
  </a>
</p>

<p align="center">
  Flame Forge2D - The bridge between Flame and Forge2D
</p>

<p align="center">
  <a title="Pub" href="https://pub.dev/packages/flame_forge2d/versions#prerelease">
    <img src="https://img.shields.io/pub/v/flame_forge2d.svg?style=popout" />
  </a>
  <img src="https://github.com/flame-engine/flame_forge2d/workflows/Test/badge.svg?branch=main&event=push" alt="Test" />
  <a title="Discord" href="https://discord.gg/pxrBmy4">
    <img src="https://img.shields.io/discord/509714518008528896.svg" />
  </a>
</p>

This library acts as a bridge between [Forge2D](https://github.com/flame-engine/forge2d) (our port
of Box2D) and the Flame game engine.


# Installation

Check [pub.dev](https://pub.dev/packages/flame_forge2d/install) for the latest version, and also
remember to add the latest version of [Flame](https://pub.dev/packages/flame/install) to your
`pubspec.yaml` file.


## Examples

In the example folder of this directory you can find some
[examples](https://github.com/flame-engine/flame/tree/main/packages/flame_forge2d/example), and you
can also find some examples in the
[Forge2D repository](https://github.com/flame-engine/forge2d/tree/main/example).


## Documentation
Some more documentation can be found
[here](https://docs.flame-engine.org/main/other_modules/forge2d.html).

==> flame_forge2d-0.12.3.tar.gz: README.md <==
<!-- markdownlint-disable MD013 -->
<p align="center">
  <a href="https://flame-engine.org">
    <img alt="flame" width="300px" src="https://raw.githubusercontent.com/flame-engine/forge2d/main/design/with-text.png">
  </a>
</p>

<p align="center">
  Flame Forge2D - The bridge between Flame and Forge2D
</p>

<p align="center">
  <a title="Pub" href="https://pub.dev/packages/flame_forge2d/versions#prerelease">
    <img src="https://img.shields.io/pub/v/flame_forge2d.svg?style=popout" />
  </a>
  <img src="https://github.com/flame-engine/flame_forge2d/workflows/Test/badge.svg?branch=main&event=push" alt="Test" />
  <a title="Discord" href="https://discord.gg/pxrBmy4">
    <img src="https://img.shields.io/discord/509714518008528896.svg" />
  </a>
</p>
<!-- markdownlint-enable MD013 -->

This library acts as a bridge between [Forge2D](https://github.com/flame-engine/forge2d) (our port
of Box2D) and the Flame game engine.


# Installation

Check [pub.dev](https://pub.dev/packages/flame_forge2d/install) for the latest version, and also
remember to add the latest version of [Flame](https://pub.dev/packages/flame/install) to your
`pubspec.yaml` file.


## Examples

In the example folder of this directory you can find some
[examples](https://github.com/flame-engine/flame/tree/main/examples/lib/stories/bridge_libraries/forge2d),
and you can also find some examples in the
[Forge2D repository](https://github.com/flame-engine/forge2d/tree/main/example).


## Documentation

Some more documentation can be found
[here](https://docs.flame-engine.org/main/other_modules/forge2d.html).
